@@ -23,7 +23,6 @@
 using namespace PGSTD;
 using namespace pqxx;
 using namespace pqxx::internal;
-using namespace pqxx::internal::pq;
 
 #define pqxxassert(ARG) /* ignore */
 
@@ -168,6 +167,7 @@ pipeline::query_id pqxx::pipeline::generate_id()
 }
 
 
+
 void pqxx::pipeline::issue()
 {
   pqxxassert(m_num_waiting);
@@ -186,16 +186,8 @@ void pqxx::pipeline::issue()
   pqxxassert(oldest != m_queries.end());
 
   // Construct cumulative query string for entire batch
-  string cum;
-  int num_issued = 0;
-  for (QueryMap::const_iterator i = oldest;
-       i != m_queries.end();
-       ++i, ++num_issued)
-  {
-    cum += i->second.get_query();
-    cum += theSeparator;
-  }
-  cum.resize(cum.size() - theSeparator.size());
+  string cum = separated_list(theSeparator,oldest,m_queries.end(),getquery());
+  const QueryMap::size_type num_issued = distance(oldest,m_queries.end());
   const bool prepend_dummy = (num_issued > 1);
   if (prepend_dummy) cum = theDummyQuery + cum;
 
