@@ -19,12 +19,13 @@
 
 #include <stdexcept>
 
+#include "libpq-fe.h"
+
 #include "pqxx/except"
 #include "pqxx/result"
 
 
 using namespace PGSTD;
-using namespace pqxx::internal::pq;
 
 
 bool pqxx::result::operator==(const result &rhs) const throw ()
@@ -72,6 +73,18 @@ bool pqxx::result::field::operator==(const field &rhs) const
 }
 
 
+pqxx::result::size_type pqxx::result::size() const throw ()
+{
+  return c_ptr() ? PQntuples(c_ptr()) : 0;
+}
+
+
+bool pqxx::result::empty() const throw ()
+{
+  return !c_ptr() || !PQntuples(c_ptr());
+}
+
+
 void pqxx::result::swap(result &rhs) throw ()
 {
   super::swap(rhs);
@@ -105,7 +118,7 @@ void pqxx::result::CheckStatus(const char Query[]) const
 string pqxx::result::StatusError() const
 {
   if (!c_ptr())
-    throw runtime_error("No result");
+    throw runtime_error("No result set given");
 
   string Err;
 
@@ -135,6 +148,21 @@ string pqxx::result::StatusError() const
 }
 
 
+const char *pqxx::result::CmdStatus() const throw ()
+{
+  return PQcmdStatus(c_ptr());
+}
+
+
+pqxx::oid pqxx::result::inserted_oid() const
+{
+  if (!c_ptr())
+    throw logic_error("Attempt to read oid of inserted row without an INSERT "
+	"result");
+  return PQoidValue(c_ptr());
+}
+
+
 pqxx::result::size_type pqxx::result::affected_rows() const
 {
   const char *const RowsStr = PQcmdTuples(c_ptr());
@@ -216,6 +244,7 @@ pqxx::result::field pqxx::result::tuple::operator[](const char f[]) const
 pqxx::result::field pqxx::result::tuple::at(const char f[]) const
 {
   const int fnum = m_Home->column_number(f);
+  // TODO: Should this be an out_of_range?
   if (fnum == -1)
     throw invalid_argument(string("Unknown field '") + f + "'");
 
@@ -244,10 +273,17 @@ pqxx::result::column_name(pqxx::result::tuple::size_type Number) const
 }
 
 
+pqxx::result::tuple::size_type pqxx::result::columns() const throw ()
+{
+  return c_ptr() ? PQnfields(c_ptr()) : 0;
+}
+
+
 pqxx::result::tuple::size_type
 pqxx::result::column_number(const char ColName[]) const
 {
   const int N = PQfnumber(c_ptr(), ColName);
+  // TODO: Should this be an out_of_range?
   if (N == -1)
     throw invalid_argument("Unknown column name: '" + string(ColName) + "'");
 
